@@ -12,5 +12,5 @@ int byte_buffer_size(void);
 void byte_buffer_purge(void);
 
 #ifndef BYTE_BUFF_SIZE
-#define BYTE_BUFF_SIZE MAX_DACT_BLK_SIZE*2
+#define BYTE_BUFF_SIZE DACT_BLK_SIZE*2
 #endif
