@@ -20,7 +20,6 @@
 
 
 #include "dact.h"
-#ifdef USE_ZLIB
 #include "comp_mzlib.h"
 #include <stdio.h>
 #include <unistd.h>
@@ -66,7 +65,9 @@ int comp_mzlib_compress(unsigned char *prev_block, unsigned char *curr_block, ch
 
 	dest_size=(int) ((float) (blk_size*1.02)+15);
 
-	tmp_block=malloc(dest_size);
+	if ((tmp_block=malloc(dest_size))==NULL) {
+		return(-1);
+	}
 	memcpy(tmp_block,curr_block,blk_size);
 
 	for (i=0;i<blk_size;i++) {
@@ -90,8 +91,7 @@ int comp_mzlib_compress(unsigned char *prev_block, unsigned char *curr_block, ch
 	retval=compress(out_block, &dest_size, tmp_block, blk_size);
 #endif
 	if (retval!=Z_OK) {
-		printf("zlib compression failed.\n");
-		return(blk_size*2);
+		return(-1);
 	}
 	free(tmp_block);
 	return(dest_size);
@@ -105,7 +105,6 @@ int comp_mzlib_decompress(unsigned char *prev_block, unsigned char *curr_block,
 	retval=uncompress(out_block,&dest_size,curr_block,blk_size);
 
 	if (retval!=Z_OK) {
-		printf("zlib decompression failed.\n");
 		return(0);
 	}
 
@@ -115,5 +114,3 @@ int comp_mzlib_decompress(unsigned char *prev_block, unsigned char *curr_block,
 
 	return(dest_size);
 }
-
-#endif
