@@ -2,7 +2,7 @@
 #include "dact.h"
 #include "config.h"
 
-#if defined(USE_MODULES) && defined(COMP_SNIBBLE_IS_MOD) && !defined(AS_MODULE)
+#if defined(USE_MODULES) && !defined(AS_MODULE)
 #define comp_snibble_algo DACT_FAILED_ALGO
 #else
 int comp_snibble_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
